searchData={"items":[{"type":"module","title":"Ecto.Adapters.ClickHouse","doc":"Adapter module for ClickHouse.\n\nIt uses `Ch` for communicating to the database.","ref":"Ecto.Adapters.ClickHouse.html"},{"type":"module","title":"Options - Ecto.Adapters.ClickHouse","doc":"All options can be given via the repository\nconfiguration:\n\n    config :your_app, YourApp.Repo,\n      ...\n\n  * `:hostname` - Server hostname (default: `\"localhost\"`)\n  * `:username` - Username\n  * `:password` - User password\n  * `:port` - HTTP Server port (default: `8123`)\n  * `:scheme` - HTTP scheme (default: `\"http\"`)\n  * `:database` - the database to connect to (default: `\"default\"`)\n  * `:settings` - Keyword list of connection settings\n  * `:transport_opts` - Options to be given to the transport being used. See `Mint.HTTP1.connect/4` for more info","ref":"Ecto.Adapters.ClickHouse.html#module-options"},{"type":"module","title":"Ecto.Adapters.ClickHouse.API","doc":"Helpers for building Ecto queries for ClickHouse.","ref":"Ecto.Adapters.ClickHouse.API.html"},{"type":"function","title":"Ecto.Adapters.ClickHouse.API.input/1","doc":"Builds an [`input(structure)`](https://clickhouse.com/docs/en/sql-reference/table-functions/input) that can be used in `Ecto.Query.from`\n\n    from i in input(a: \"Int16\", b: :string)\n    from i in input(Schema)","ref":"Ecto.Adapters.ClickHouse.API.html#input/1"},{"type":"task","title":"mix ecto.ch.schema","doc":"Shows an Ecto schema hint for a ClickHouse table.\n\nExamples:\n\n    $ mix ecto.ch.schema\n    $ mix ecto.ch.schema system.numbers\n    $ mix ecto.ch.schema system.numbers --repo MyApp.Repo","ref":"Mix.Tasks.Ecto.Ch.Schema.html"},{"type":"function","title":"Mix.Tasks.Ecto.Ch.Schema.run/1","doc":"","ref":"Mix.Tasks.Ecto.Ch.Schema.html#run/1"},{"type":"extras","title":"Ecto ClickHouse Adapter","doc":"# Ecto ClickHouse Adapter\n\n[![Hex Package](https://img.shields.io/hexpm/v/ecto_ch.svg)](https://hex.pm/packages/ecto_ch)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/ecto_ch)\n\nUses [Ch](https://github.com/plausible/ch) as driver.","ref":"readme.html"},{"type":"extras","title":"Installation - Ecto ClickHouse Adapter","doc":"```elixir\ndefp deps do\n  [\n    {:ecto_ch, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Ecto ClickHouse Adapter","doc":"In your `config/config.exs`\n\n```elixir\nconfig :my_app, ecto_repos: [MyApp.Repo]\nconfig :my_app, MyApp.Repo, url: \"http://username:password@localhost:8123/database\"\n```\n\nIn your application code\n\n```elixir\ndefmodule MyApp.Repo do\n  use Ecto.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.ClickHouse\nend\n```\n\nOptionally you can also set the default table engine and options to use in migrations\n\n```elixir\nconfig :ecto_ch,\n  default_table_engine: \"TinyLog\",\n  default_table_options: [cluster: \"little-giant\", order_by: \"tuple()\"]\n```\n\n##","ref":"readme.html#usage"},{"type":"extras","title":"Ecto schemas - Ecto ClickHouse Adapter","doc":"For automatic RowBinary encoding please use the custom `Ch` Ecto type:\n\n```elixir\ndefmodule MyApp.Example do\n  use Ecto.Schema\n\n  @primary_key false\n  schema \"example\" do\n    field :number, Ch, type: \"UInt32\"\n    field :name, Ch, type: \"String\"\n    field :maybe_name, Ch, type: \"Nullable(String)\"\n    field :country_code, Ch, type: \"FixedString(2)\"\n    field :price, Ch, type: \"Decimal32(2)\"\n    field :map, Ch, type: \"Map(String, UInt64)\"\n    field :ipv4, Ch, type: \"IPv4\"\n    field :ipv4s, {:array, Ch}, type: \"IPv4\"\n    field :enum, Ch, type: \"Enum8('hello' = 1, 'world' = 2)\"\n    # etc.\n  end\nend\n\nMyApp.Repo.insert_all(MyApp.Example, rows)\n```\n\nSome Ecto types like `:string`, `:date`, and `Ecto.UUID` would also work. Others like `:decimal`, `:integer` are ambiguous and should not be used.\n\n[`ecto.ch.schema`](https://hexdocs.pm/ecto_ch/Mix.Tasks.Ecto.Ch.Schema.html) mix task can be used to generate a schema from an existing ClickHouse table.\n\n##","ref":"readme.html#ecto-schemas"},{"type":"extras","title":"Schemaless inserts - Ecto ClickHouse Adapter","doc":"For schemaless inserts `:types` option with a mapping of `field->type` needs to be provided:\n\n```elixir\ntypes = [\n  number: \"UInt32\",\n  # or `number: :u32`\n  # or `number: Ch.Types.u32()`\n  # etc.\n]\n\nMyApp.Repo.insert_all(\"example\", rows, types: types)\n```\n\n##","ref":"readme.html#schemaless-inserts"},{"type":"extras","title":"Settings - Ecto ClickHouse Adapter","doc":"`:settings` option can be used to enable [asynchronous inserts,](https://clickhouse.com/docs/en/optimize/asynchronous-inserts) lightweight [deletes,](https://clickhouse.com/docs/en/guides/developer/lightweght-delete) global [FINAL](https://clickhouse.com/docs/en/operations/settings/settings#final) modifier, and [more:](https://clickhouse.com/docs/en/operations/settings/settings)\n\n```elixir\nMyApp.Repo.insert_all(MyApp.Example, rows, settings: [async_insert: 1])\nMyApp.Repo.delete_all(\"example\", settings: [allow_experimental_lightweight_delete: 1])\nMyApp.Repo.all(MyApp.AggregatedExample, settings: [final: 1])\n```\n\n##","ref":"readme.html#settings"},{"type":"extras","title":"Migrations - Ecto ClickHouse Adapter","doc":"ClickHouse-specific options can be passed into `table.options` and `index.options`\n\n```elixir\ntable_options = [cluster: \"my-cluster\"]\nengine_options = [order_by: \"tuple()\"]\noptions = table_options ++ engine_options\n\ncreate table(:posts, primary_key: false, engine: \"ReplicatedMergeTree\", options: options) do\n  add :message, :string\n  add :user_id, :UInt64\nend\n```\n\nis equivalent to\n\n```sql\nCREATE TABLE `posts` ON CLUSTER `my-cluster` (\n  `message` String,\n  `user_id` UInt64\n) ENGINE ReplicatedMergeTree ORDER BY tuple()\n```","ref":"readme.html#migrations"},{"type":"extras","title":"Caveats - Ecto ClickHouse Adapter","doc":"#### [ARRAY JOIN](https://clickhouse.com/docs/en/sql-reference/statements/select/array-join)\n\nSince [`v3.10.2`](https://github.com/elixir-ecto/ecto/blob/40133ace8c71f1f81432858e71d3d73527f85107/CHANGELOG.md?plain=1#L10) Ecto supports `:array` and `:left_array` join types:\n\n```elixir\nfrom a in \"arrays_test\", array_join: r in \"arr\", select: {a.s, r}\n```\n\nFor an earlier Ecto version `:inner_lateral` and `:left_lateral` join types can be used instead:\n\n```elixir\nfrom a in \"arrays_test\", inner_lateral_join: r in \"arr\", select: {a.s, r}\n```\n\nBoth of these queries are equivalent to:\n\n```sql\nSELECT a0.\"s\", a1 FROM \"arrays_test\" AS a0 ARRAY JOIN \"arr\" AS a1\n```\n\n##","ref":"readme.html#caveats"},{"type":"extras","title":"NULL - Ecto ClickHouse Adapter","doc":"`DEFAULT` expressions on columns are ignored when inserting RowBinary.\n\n[See Ch for more details and an example.](https://github.com/plausible/ch#null-in-rowbinary)","ref":"readme.html#null"},{"type":"extras","title":"Benchmarks - Ecto ClickHouse Adapter","doc":"[See Ch for benchmarks.](https://github.com/plausible/ch#benchmarks)","ref":"readme.html#benchmarks"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.3.1 (2023-11-11) - Changelog","doc":"- raise on `validate: true` in `CHECK` constraints https://github.com/plausible/ecto_ch/pull/124\n- add support for unsafe hints https://github.com/plausible/ecto_ch/pull/102\n- lookup types for aliased Ecto.Schema fields https://github.com/plausible/ecto_ch/pull/137","ref":"changelog.html#0-3-1-2023-11-11"},{"type":"extras","title":"0.3.0 (2023-09-13) - Changelog","doc":"- ensure all colums are for the same table in `ecto.ch.schema` mix task https://github.com/plausible/ecto_ch/pull/118\n- switch from `CREATE INDEX` to `ALTER TABLE ... ADD INDEX` syntax for indexes https://github.com/plausible/ecto_ch/pull/120\n- raise on `CREATE INDEX CONCURRENTLY` https://github.com/plausible/ecto_ch/pull/121\n- switch from `DROP INDEX` to `ALTER TABLE ... DROP INDEX` syntax for indexes https://github.com/plausible/ecto_ch/pull/122\n- add support for structured `:options` in migrations https://github.com/plausible/ecto_ch/pull/116\n- add `:default_table_options` option https://github.com/plausible/ecto_ch/pull/123","ref":"changelog.html#0-3-0-2023-09-13"},{"type":"extras","title":"0.2.2 (2023-08-29) - Changelog","doc":"- use our http client for `structure_load` https://github.com/plausible/ecto_ch/pull/111","ref":"changelog.html#0-2-2-2023-08-29"},{"type":"extras","title":"0.2.1 (2023-08-28) - Changelog","doc":"- added constraint support in migrations https://github.com/plausible/ecto_ch/pull/108","ref":"changelog.html#0-2-1-2023-08-28"},{"type":"extras","title":"0.2.0 (2023-07-28) - Changelog","doc":"- refactor dumpers and loaders https://github.com/plausible/ecto_ch/pull/92 -- this is the reason for minor version bumping\n- improve `ecto.ch.schema` mix task https://github.com/plausible/ecto_ch/pull/83","ref":"changelog.html#0-2-0-2023-07-28"},{"type":"extras","title":"0.1.11 (2023-06-12) - Changelog","doc":"- add support for `:array_join` and `:left_array_join` types https://github.com/plausible/ecto_ch/pull/76\n- add preliminary support for inserts via `:input` https://github.com/plausible/ecto_ch/pull/79","ref":"changelog.html#0-1-11-2023-06-12"},{"type":"extras","title":"0.1.10 (2023-06-01) - Changelog","doc":"- add support for `type(..., :any)` https://github.com/plausible/ecto_ch/pull/78","ref":"changelog.html#0-1-10-2023-06-01"},{"type":"extras","title":"0.1.9 (2023-05-24) - Changelog","doc":"- update `:ch`","ref":"changelog.html#0-1-9-2023-05-24"},{"type":"extras","title":"0.1.8 (2023-05-24) - Changelog","doc":"- fix string types in schemaless inserts https://github.com/plausible/ecto_ch/pull/75","ref":"changelog.html#0-1-8-2023-05-24"},{"type":"extras","title":"0.1.7 (2023-05-24) - Changelog","doc":"- add `insert_stream` https://github.com/plausible/ecto_ch/pull/74","ref":"changelog.html#0-1-7-2023-05-24"},{"type":"extras","title":"0.1.6 (2023-05-23) - Changelog","doc":"- make types more strict https://github.com/plausible/ecto_ch/pull/69","ref":"changelog.html#0-1-6-2023-05-23"},{"type":"extras","title":"0.1.5 (2023-05-23) - Changelog","doc":"- require `:ch` to be `~> 0.1.10` https://github.com/plausible/ecto_ch/pull/71","ref":"changelog.html#0-1-5-2023-05-23"},{"type":"extras","title":"0.1.4 (2023-05-05) - Changelog","doc":"- improve `:array` type handling https://github.com/plausible/ecto_ch/pull/67","ref":"changelog.html#0-1-4-2023-05-05"},{"type":"extras","title":"0.1.3 (2023-05-01) - Changelog","doc":"- fix `in` params https://github.com/plausible/ecto_ch/pull/64","ref":"changelog.html#0-1-3-2023-05-01"},{"type":"extras","title":"0.1.2 (2023-04-28) - Changelog","doc":"- add `mix ecto.load` support https://github.com/plausible/ecto_ch/pull/60","ref":"changelog.html#0-1-2-2023-04-28"},{"type":"extras","title":"0.1.1 (2023-04-26) - Changelog","doc":"- add `:default_table_engine` option https://github.com/plausible/ecto_ch/pull/58\n- add `ecto.ch.schema` mix task https://github.com/plausible/ecto_ch/pull/59","ref":"changelog.html#0-1-1-2023-04-26"}],"content_type":"text/markdown"}